==> cmsmadesimple-1.7.1-full.tar.gz: modules/TinyMCE/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE  WYSIWYG';
$lang['uninstalled'] = 'Modulis i&scaron;diegtas';
$lang['installed'] = 'Modulio %s versija įdiegta.';
$lang['stripbackgroundtags'] = 'I&scaron;imti Background žymes i&scaron; CSS';
$lang['stiptags_help'] = 'This options tries to remove background-type settings from the stylesheet.';
$lang['source_formatting_text'] = 'Pritaikyti kodo formatavimą HTML vaizdavimui';
$lang['dropdownblockformats_text'] = 'Neleidžiami formatai i&scaron;&scaron;okančiam pasirenkamam meniu';
$lang['allowtables'] = 'Leisti lentelių naudojimą';
$lang['newlinestyle_text'] = 'Naujos eilutės stilius';
$lang['pstyle'] = 'p stilius';
$lang['brstyle'] = 'br stilius';
$lang['usecompressiontext'] = 'Naudoti gz suspaudimą';
$lang['usecompressionhelp'] = 'Tai gali pagreitinti  TinyMCE, bet kai kuriose sistemose gali neužkrauti. Naudokite atsargiai.';
$lang['forcedrootblocktext'] = 'Priverstinis <p> naudojimas';
$lang['forcedrootblockhelp'] = 'Priversti pastraipas naudoti <p>-tag';
$lang['filepickerstyle'] = 'Bylų pasirinkimo stilius';
$lang['filepickersize'] = 'Bylų pasirinkimo dydis';
$lang['allowuploadtext'] = 'Allow upload and creating dirs in FilePicker';
$lang['allowscalingtext'] = 'Allow on-the-fly resizing of uploaded images';
$lang['scalingdimensionstext'] = 'Numatytos dimensijos';
$lang['resizeto'] = 'Pakeisti dydį į';
$lang['useadvancedprofile'] = 'Use advanced TinyMCE-profile';
$lang['saveprofile'] = 'Saugoti profilį';
$lang['profilesaved'] = 'Profilis buvo i&scaron;saugotas';
$lang['profiles_tab'] = 'Profiliai';
$lang['advanced_backend_toolbars'] = 'Advanced backend profile settings';
$lang['savestyles'] = 'Save styles';
$lang['allowadvancedprofile'] = 'Allow usage of advanced profile in TinyMCE';
$lang['showfilemanagement'] = 'Show filemanagement options';
$lang['showfilemanagementhelp'] = 'Show filemanagement in options like upload, make dir and file deletion in FilePicker, if the user is allowed to perform these.';
$lang['deleteconfirmation'] = 'Are you sure this file should be deleted?';
$lang['deletefilesuccess'] = 'was successfully deleted';
$lang['deletefilefila'] = 'could not be deleted';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'Rodyti pavadinimus';
$lang['thumbnailsonly'] = 'Rodyti miniatiūras';
$lang['showthumbnailfilestext'] = 'Show thumbnail-files in lists';
$lang['filenameandthumbnails'] = 'Rodyti tiek miniatiūras tiek pavadinimus';
$lang['skinstext'] = 'Oda';
$lang['skinvariationtext'] = 'Odos variacija';
$lang['advancedwarning'] = '<strong>Pra&scaron;ome atminti!<br/>
Pakeisdami &scaron;ias nuostatas TinyMCE gali nebeveikti ar generuoti kodą neteisingai. Čia redaguokite jei žinote ką darote. Pra&scaron;ome pasikonsultuoti TinyMCE svetainėje prie&scaron; keičiant.</strong>';
$lang['entityencoding_text'] = 'Kodavimas';
$lang['rawencoding'] = 'Pavir&scaron;utinis kodavimas (greičiausias, veikia daugeliu atveju)';
$lang['namedencoding'] = 'Pavadintas kodavimas (kaip &nbsp;)';
$lang['numericencoding'] = 'Skaitinis kodavimas (kaip &amp;amp;#160;)';
$lang['show_path_text'] = 'Rodyti elemento kelia redaktoriaus apačioje';
$lang['toolbar_tab'] = 'Įrankinė ';
$lang['toolbar_help'] = '&Scaron;ios nuostatos turėtų būt sudarytos i&scaron; kableliu atskirtų mygtukų pavadinimų.';
$lang['toolbar_text'] = 'Įrankinė ';
$lang['toolbarhelptext'] = 'Spauskite čia jei norite peržiūrėti TinyMCE įrankinės instrikcija.';
$lang['editor_width_text'] = 'Redaktoriaus lauko plotis';
$lang['editor_height_text'] = 'Redaktoriaus lauko auk&scaron;tis';
$lang['auto'] = 'Automatinis';
$lang['or'] = 'ar';
$lang['datetimeformat_text'] = 'Datos/Laiko formatas';
$lang['timetext'] = 'Laikas';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Spauskite čia jei norite pagalbos dėl laiko datos formatavimo';
$lang['extraconfigtext'] = 'Papildomi nustatymai';
$lang['extraconfighelp'] = 'Patikrinkite TinyMCE-wiki';
$lang['customdropdowntext'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['customdropdownhelp'] = 'Įterpia savitus kodo teksto fragmentus į i&scaron;skleidžiamąjį meniu. Naudojama paprastesniam žymių naudojimui. Meniu įterpiamas į įrankinę naudojant &#039;customdropdown&#039;.
';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Užkrauti CMS-linker';
$lang['loadcmslinkerhelp'] = 'Tai sugeneruoja javascript-kodą reikalingą pridėti į įrankinę
';
$lang['cmslinkerstyletext'] = 'CMS-linker nuorodų stilius';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stilius (palaiko &scaron;varius url)';
$lang['ahrefstyle'] = '<a href>-stilius (nepalaiko &scaron;varių url)';
$lang['relativeurlstext'] = 'Generuoti giminingus url';
$lang['forcecleanpastetext'] = 'Priverstinis &scaron;varus įterpimas (paste)';
$lang['forcecleanpastehelp'] = 'Tai turėtų būt įjungta jei norite pa&scaron;alinti keistą Word formatavimą kai įterpiamas tekstas.';
$lang['bodycss_text'] = 'Body tag&#039;as CSS';
$lang['bodycss_help'] = 'Bus pridėtas į css body-apibrėžimą';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Naudoti statinę konfiguracijos bylą';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamically created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'Rodyti žyminą laukelį i&scaron;jungti/įjungti  WYSIWYG';
$lang['togglewysiwyg'] = 'Įjungti/i&scaron;jungti WYSIWYG';
$lang['styles_tab'] = 'CSS Stiliai';
$lang['styles_help'] = 'Jei paliksite tu&scaron;čia, TinyMCE naudos CSS bylą ir stilius esančius joje. Jei norite leisti nariams naudoti tik tam tikrus stilius nurodykite juos forma &quot;SavitasPavadinimas1=stilius1; SavitasPavadinimas2=tilius2&quot; pirmame laukelyje';
$lang['css_styles_text'] = 'Stiliai';
$lang['accessdenied'] = 'Prieiga uždrausta. Pasitirinkite leidimus.';
$lang['error'] = 'Klaida!';
$lang['submit'] = 'Pateikti';
$lang['update'] = 'Atnaujinti';
$lang['savesettings'] = 'Saugoti nustatymus';
$lang['settings'] = 'Nuostatos';
$lang['settingssaved'] = 'Nuostatos i&scaron;saugotos';
$lang['saveadvanced'] = 'Saugoti i&scaron;plėstuosius nustatymus';
$lang['advancedsaved'] = 'Pažangesnės nuostatos i&scaron;saugotos';
$lang['toolbarsaved'] = 'Įrankinė i&scaron;saugoti';
$lang['stylessaved'] = 'Stiliai i&scaron;saugoti';
$lang['testareatext'] = '<p>Testavimo erdvė, joks tekstas nebus i&scaron;saugotas testavimo metu...</p>';
$lang['reset'] = 'Atstatyti į pradinius';
$lang['resetall'] = 'Nustatyti visas nuostatas į pradines';
$lang['confirmreset'] = 'Ar tikrai norite atstatyti nuostatas į pradinies?';
$lang['confirmresetall'] = 'Ar tikrai norite atstatyti VISAS nuostatas į pradinies?';
$lang['settingsreset'] = 'Nuostatos atstatytos';
$lang['allsettingsreset'] = 'Visos nuostatos atstatytos';
$lang['upgraded'] = 'buvo atnaujinta į versija';
$lang['customdropdown'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['cmsmslinker'] = 'Įterpti nuorodą į cmsms-puslapį';
$lang['backend_toolbars'] = 'Administratoriaus įrankinės nuostatos';
$lang['frontend_toolbars'] = 'Prie&scaron;akinės įrankinės nuostatos';
$lang['plugins_tab'] = 'Plėtiniai';
$lang['plugins_help'] = 'Pasirinkite kokius plėtinius norite aktyvuoti. Dokumentacija rasite <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">čia</a>';
$lang['plugins_text'] = 'Plėtiniai';
$lang['saveplugins'] = 'I&scaron;saugoti plėtinius';
$lang['pluginssaved'] = 'Plėtiniai i&scaron;saugoti';
$lang['youareintext'] = 'Jūs esate';
$lang['loadstylesheettext'] = 'Load stylesheet for content (recommended)';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'Nauja byla';
$lang['uploadfile'] = 'Įkelti';
$lang['createnewdir'] = 'Naujas katalogas';
$lang['createdir'] = 'Sukurti';
$lang['nodirname'] = 'Nepateiktas katalogo pavadinimas';
$lang['direxists'] = 'Katalogas tokiu pavadinumu jau egzistuoja';
$lang['newdircreated'] = 'Naujas katalogas sėkmingai sukurtas';
$lang['newdirfailed'] = 'Įvyko klaida kuriant katalogą';
$lang['nofile'] = 'Byla nebuvo įkelta';
$lang['filetoobig'] = 'Įkelta byla yra per didelė';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Klaida  perkeliant įkeltą bylą';
$lang['fileuploaded'] = 'Byla sėkmingai įkelta';
$lang['filepickertitle'] = 'CMSMadeSimple Bylų pasirinkimas';
$lang['success'] = 'Sėkmė';
$lang['fileoperations'] = 'Veiksmai su bylomis';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dydis';
$lang['dimensions'] = 'hxw';
$lang['advanced_tab'] = 'Papildomai';
$lang['help'] = '	<h3>Ką jis daro?</h3>
	<p>Naudoja TinyMCE kaip WYSIWYG html redaktorių.</p>
	<h3>Kaip jį naudoti?</h3>
	<p>Įdiegite jį, nueikite į Vartotojo Nustatymus ir pažymėkite, kad norite naudoti TinyMCE kaip WYSIWYG redaktorių.</p>

	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['qca'] = 'P0-397021319-1259924410830';
$lang['utma'] = '156861353.499712353.1260116687.1260116687.1260116687.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1260116687.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
?>

==> cmsmadesimple-1.9.4.2-full.tar.gz: modules/TinyMCE/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE  WYSIWYG';
$lang['uninstalled'] = 'Modulis i&scaron;diegtas';
$lang['installed'] = 'Modulio %s versija įdiegta.';
$lang['stripbackgroundtags'] = 'I&scaron;imti Background žymes i&scaron; CSS';
$lang['stiptags_help'] = 'This options tries to remove background-type settings from the stylesheet.';
$lang['source_formatting_text'] = 'Pritaikyti kodo formatavimą HTML vaizdavimui';
$lang['dropdownblockformats_text'] = 'Neleidžiami formatai i&scaron;&scaron;okančiam pasirenkamam meniu';
$lang['allowtables'] = 'Leisti lentelių naudojimą';
$lang['newlinestyle_text'] = 'Naujos eilutės stilius';
$lang['pstyle'] = 'p stilius';
$lang['brstyle'] = 'br stilius';
$lang['usecompressiontext'] = 'Naudoti gz suspaudimą';
$lang['usecompressionhelp'] = 'Tai gali pagreitinti  TinyMCE, bet kai kuriose sistemose gali neužkrauti. Naudokite atsargiai.';
$lang['forcedrootblocktext'] = 'Priverstinis <p> naudojimas';
$lang['forcedrootblockhelp'] = 'Priversti pastraipas naudoti <p>-tag';
$lang['filepickerstyle'] = 'Bylų pasirinkimo stilius';
$lang['filepickersize'] = 'Bylų pasirinkimo dydis';
$lang['allowuploadtext'] = 'Allow upload and creating dirs in FilePicker';
$lang['allowscalingtext'] = 'Allow on-the-fly resizing of uploaded images';
$lang['scalingdimensionstext'] = 'Numatytos dimensijos';
$lang['resizeto'] = 'Pakeisti dydį į';
$lang['makethumbnail'] = 'Make a thumbnail when uploading images';
$lang['useadvancedprofile'] = 'Use advanced TinyMCE-profile';
$lang['saveprofile'] = 'Saugoti profilį';
$lang['profilesaved'] = 'Profilis buvo i&scaron;saugotas';
$lang['profiles_tab'] = 'Profiliai';
$lang['advanced_backend_toolbars'] = 'Advanced backend profile settings';
$lang['savestyles'] = 'Saugoti stilius';
$lang['allowadvancedprofile'] = 'Allow usage of advanced profile in TinyMCE';
$lang['showfilemanagement'] = 'Show filemanagement options';
$lang['showfilemanagementhelp'] = 'Show filemanagement in options like upload, make dir and file deletion in FilePicker, if the user is allowed to perform these.';
$lang['restrictdirs'] = 'Restrict user&#039;s dir access';
$lang['restrictdirshelp'] = 'This will restrict the filemanagement-capabilities of the user to a subdir to &#039;uploads&#039; which have the same name as the user&#039;s login. If the subdir does not exist, it will possibly be created. Please note, this currently only works with the standard dirnames, uploads/images. This may change in the future.';
$lang['deleteconfirmation'] = 'Ar tikrai norite i&scaron;trinti &scaron;į failą?';
$lang['deletefilesuccess'] = 'buvo sėkmingai i&scaron;trintas';
$lang['deletefilefailed'] = 'negali būti i&scaron;trintas';
$lang['deletesubdirfailed'] = 'negali būti i&scaron;trintas';
$lang['deletesubdirsuccess'] = 'buvo sėkmingai i&scaron;trintas';
$lang['deletedirconfirmation'] = 'Are you sure this empty subdir should be deleted?';
$lang['deletedir'] = 'Trinti tu&scaron;čią sub-katalogą';
$lang['deletefile'] = 'Trinti failą';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'Rodyti pavadinimus';
$lang['thumbnailsonly'] = 'Rodyti miniatiūras';
$lang['showthumbnailfilestext'] = 'Show thumbnail-files in lists';
$lang['filenameandthumbnails'] = 'Rodyti tiek miniatiūras tiek pavadinimus';
$lang['skinstext'] = 'Oda';
$lang['skinvariationtext'] = 'Odos variacija';
$lang['advancedwarning'] = '<strong>Pra&scaron;ome atminti!<br/>
Pakeisdami &scaron;ias nuostatas TinyMCE gali nebeveikti ar generuoti kodą neteisingai. Čia redaguokite jei žinote ką darote. Pra&scaron;ome pasikonsultuoti TinyMCE svetainėje prie&scaron; keičiant.</strong>';
$lang['entityencoding_text'] = 'Kodavimas';
$lang['rawencoding'] = 'Pavir&scaron;utinis kodavimas (greičiausias, veikia daugeliu atveju)';
$lang['namedencoding'] = 'Pavadintas kodavimas (kaip &nbsp;)';
$lang['numericencoding'] = 'Skaitinis kodavimas (kaip &amp;amp;#160;)';
$lang['show_path_text'] = 'Rodyti elemento kelia redaktoriaus apačioje';
$lang['toolbar_tab'] = 'Įrankinė ';
$lang['toolbar_help'] = '&Scaron;ios nuostatos turėtų būt sudarytos i&scaron; kableliu atskirtų mygtukų pavadinimų.';
$lang['toolbar_text'] = 'Įrankinė ';
$lang['toolbarhelptext'] = 'Spauskite čia jei norite peržiūrėti TinyMCE įrankinės instrikcija.';
$lang['editor_width_text'] = 'Redaktoriaus lauko plotis';
$lang['editor_height_text'] = 'Redaktoriaus lauko auk&scaron;tis';
$lang['auto'] = 'Automatinis';
$lang['or'] = 'ar';
$lang['allowresizing'] = 'Allow inplace resizing of editor field';
$lang['resizenone'] = 'Do not allow resizing';
$lang['resizeboth'] = 'Allow resizing in both directions';
$lang['resizeheight'] = 'Allow resizing of height only';
$lang['datetimeformat_text'] = 'Datos/Laiko formatas';
$lang['timetext'] = 'Laikas';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Spauskite čia jei norite pagalbos dėl laiko datos formatavimo';
$lang['extraconfigtext'] = 'Papildomi nustatymai';
$lang['extraconfighelp2'] = 'One statement per line, commas will be added before and after this content. Check TinyMCE-wiki for instructions.';
$lang['customdropdowntext'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['customdropdownhelp'] = 'Įterpia savitus kodo teksto fragmentus į i&scaron;skleidžiamąjį meniu. Naudojama paprastesniam žymių naudojimui. Meniu įterpiamas į įrankinę naudojant &#039;customdropdown&#039;.
';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Užkrauti CMS-linker';
$lang['loadcmslinkerhelp'] = 'Tai sugeneruoja javascript-kodą reikalingą pridėti į įrankinę
';
$lang['cmslinkerstyletext'] = 'CMS-linker nuorodų stilius';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stilius (palaiko &scaron;varius url)';
$lang['ahrefstyle'] = '<a href>-stilius (nepalaiko &scaron;varių url)';
$lang['relativeurlstext'] = 'Generuoti giminingus url';
$lang['forcecleanpastetext'] = 'Priverstinis &scaron;varus įterpimas (paste)';
$lang['forcecleanpastehelp'] = 'Tai turėtų būt įjungta jei norite pa&scaron;alinti keistą Word formatavimą kai įterpiamas tekstas.';
$lang['bodycss_text'] = 'Body tag&#039;as CSS';
$lang['bodycss_help'] = 'Bus pridėtas į css body-apibrėžimą';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Naudoti statinę konfiguracijos bylą';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamically created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['ignoremodifyfilestext'] = 'Ignore the &#039;Modify Files&#039; permission for FilePicker';
$lang['ignoremodifyfileshelp'] = 'Warning! This allows some file-altering operations even if the &#039;Modify Files&#039; permission is not set for the current usergroup. This can effectively be used together with the option to restrict user&#039;s directory access.';
$lang['showtogglebutton_text'] = 'Rodyti žyminą laukelį i&scaron;jungti/įjungti  WYSIWYG';
$lang['togglewysiwyg'] = 'Įjungti/i&scaron;jungti WYSIWYG';
$lang['styles_tab'] = 'CSS Stiliai';
$lang['styles_help'] = 'Jei paliksite tu&scaron;čia, TinyMCE naudos CSS bylą ir stilius esančius joje. Jei norite leisti nariams naudoti tik tam tikrus stilius nurodykite juos forma &quot;SavitasPavadinimas1=stilius1; SavitasPavadinimas2=tilius2&quot; pirmame laukelyje';
$lang['css_styles_text'] = 'Stiliai';
$lang['accessdenied'] = 'Prieiga uždrausta. Pasitirinkite leidimus.';
$lang['error'] = 'Klaida!';
$lang['submit'] = 'Pateikti';
$lang['update'] = 'Atnaujinti';
$lang['savesettings'] = 'Saugoti nustatymus';
$lang['settings'] = 'Nuostatos';
$lang['settingssaved'] = 'Nuostatos i&scaron;saugotos';
$lang['saveadvanced'] = 'Saugoti i&scaron;plėstuosius nustatymus';
$lang['advancedsaved'] = 'Pažangesnės nuostatos i&scaron;saugotos';
$lang['toolbarsaved'] = 'Įrankinė i&scaron;saugoti';
$lang['stylessaved'] = 'Stiliai i&scaron;saugoti';
$lang['testareatext'] = '<p>Testavimo erdvė, joks tekstas nebus i&scaron;saugotas testavimo metu...</p>';
$lang['reset'] = 'Atstatyti į pradinius';
$lang['resetall'] = 'Nustatyti visas nuostatas į pradines';
$lang['confirmreset'] = 'Ar tikrai norite atstatyti nuostatas į pradinies?';
$lang['confirmresetall'] = 'Ar tikrai norite atstatyti VISAS nuostatas į pradinies?';
$lang['settingsreset'] = 'Nuostatos atstatytos';
$lang['allsettingsreset'] = 'Visos nuostatos atstatytos';
$lang['upgraded'] = 'buvo atnaujinta į versija';
$lang['customdropdown'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['cmsmslinker'] = 'Įterpti nuorodą į cmsms-puslapį';
$lang['backend_toolbars'] = 'Administratoriaus įrankinės nuostatos';
$lang['frontend_toolbars'] = 'Prie&scaron;akinės įrankinės nuostatos';
$lang['plugins_tab'] = 'Plėtiniai';
$lang['plugins_help'] = 'Pasirinkite kokius plėtinius norite aktyvuoti. Dokumentacija rasite <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">čia</a>';
$lang['plugins_text'] = 'Plėtiniai';
$lang['saveplugins'] = 'I&scaron;saugoti plėtinius';
$lang['plugins_module'] = 'Module Plugins';
$lang['plugins_common'] = 'Common Plugins';
$lang['module'] = 'Modulis';
$lang['description'] = 'Apra&scaron;ymas';
$lang['plugin'] = 'Plugin';
$lang['youareintext'] = 'Jūs esate';
$lang['loadstylesheettext'] = 'Load stylesheet for content (recommended)';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'Nauja byla';
$lang['uploadfile'] = 'Įkelti';
$lang['createnewdir'] = 'Naujas katalogas';
$lang['createdir'] = 'Sukurti';
$lang['nodirname'] = 'Nepateiktas katalogo pavadinimas';
$lang['direxists'] = 'Katalogas tokiu pavadinumu jau egzistuoja';
$lang['newdircreated'] = 'Naujas katalogas sėkmingai sukurtas';
$lang['newdirfailed'] = 'Įvyko klaida kuriant katalogą';
$lang['nofile'] = 'Byla nebuvo įkelta';
$lang['filetoobig'] = 'Įkelta byla yra per didelė';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Klaida  perkeliant įkeltą bylą';
$lang['fileuploaded'] = 'Byla sėkmingai įkelta';
$lang['filepickertitle'] = 'CMSMadeSimple Bylų pasirinkimas';
$lang['success'] = 'Sėkmė';
$lang['fileoperations'] = 'Veiksmai su bylomis';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dydis';
$lang['dimensions'] = 'hxw';
$lang['advanced_tab'] = 'Papildomai';
$lang['help'] = '	<h3>Ką jis daro?</h3>
	<p>Naudoja TinyMCE kaip WYSIWYG html redaktorių.</p>
	<h3>Kaip jį naudoti?</h3>
	<p>Įdiegite jį, nueikite į Vartotojo Nustatymus ir pažymėkite, kad norite naudoti TinyMCE kaip WYSIWYG redaktorių.</p>

	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['qca'] = 'P0-397021319-1259924410830';
$lang['utma'] = '156861353.499712353.1260116687.1272125657.1272925371.65';
$lang['utmz'] = '156861353.1272925371.65.49.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
